oumi.performance
================
.. py:module:: oumi.performance

Submodules
----------

oumi.performance.mfu module
---------------------------

.. automodule:: oumi.performance.mfu
   :members:
   :undoc-members:
   :show-inheritance:

oumi.performance.telemetry module
---------------------------------

.. automodule:: oumi.performance.telemetry
   :members:
   :undoc-members:
   :show-inheritance:

oumi.performance.torch\_profiler\_utils module
----------------------------------------------

.. automodule:: oumi.performance.torch_profiler_utils
   :members:
   :undoc-members:
   :show-inheritance:
